@@ -1,14 +1,16 @@
 /*
  * dbus.c -- D-BUS interface
- * Copyright (C) 2007 Alberto Garcia <agarcia@igalia.com>
- * Copyright (C) 2008 Mario Sanchez Prada <msanchez@igalia.com>
+ *
+ * Copyright (C) 2007-2009 Igalia, S.L.
+ * Authors: Mario Sanchez Prada <msanchez@igalia.com>
+ *          Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3
  * See the README file for more details.
  */
 
 #include "dbus.h"
-#include "controller.h"
+#include "compat.h"
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
@@ -19,104 +21,107 @@
 static DBusConnection *dbus_connection = NULL;
 static gboolean dbus_filter_added = FALSE;
 
+static void
+player_stopped_cb                       (VglController *ctrl,
+                                         gpointer       data)
+{
+        lastfm_dbus_notify_playback (NULL);
+}
+
+static void
+track_started_cb                        (VglController *ctrl,
+                                         LastfmTrack   *track,
+                                         gpointer       data)
+{
+        lastfm_dbus_notify_playback (track);
+}
+
+static void
+controller_destroyed_cb                 (gpointer  data,
+                                         GObject  *controller)
+{
+        lastfm_dbus_notify_closing();
+        lastfm_dbus_close();
+}
+
 static gboolean
-playurl_handler_idle(gpointer data)
+playurl_handler_idle                    (gpointer data)
 {
         g_return_val_if_fail(data != NULL, FALSE);
         char *url = (char *) data;
-        gdk_threads_enter();
         controller_play_radio_by_url(url);
-        gdk_threads_leave();
         g_free(url);
         return FALSE;
 }
 
 static gboolean
-play_handler_idle(gpointer data)
+play_handler_idle                       (gpointer data)
 {
-        gdk_threads_enter();
         controller_start_playing();
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-stop_handler_idle(gpointer data)
+stop_handler_idle                       (gpointer data)
 {
-        gdk_threads_enter();
         controller_stop_playing();
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-skip_handler_idle(gpointer data)
+skip_handler_idle                       (gpointer data)
 {
-        gdk_threads_enter();
         controller_skip_track();
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-lovetrack_handler_idle(gpointer data)
+lovetrack_handler_idle                  (gpointer data)
 {
         gboolean interactive = (gboolean)GPOINTER_TO_INT(data);
-        gdk_threads_enter();
         controller_love_track(interactive);
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-bantrack_handler_idle(gpointer data)
+bantrack_handler_idle                   (gpointer data)
 {
         gboolean interactive = (gboolean)GPOINTER_TO_INT(data);
-        gdk_threads_enter();
         controller_ban_track(interactive);
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-showwindow_handler_idle(gpointer data)
+showwindow_handler_idle                 (gpointer data)
 {
         gboolean show = GPOINTER_TO_INT(data);
-        gdk_threads_enter();
         controller_show_mainwin(show);
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-volumechange_handler_idle(gpointer data)
+volumechange_handler_idle               (gpointer data)
 {
         gint volchange = GPOINTER_TO_INT(data);
-        gdk_threads_enter();
         controller_increase_volume(volchange);
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-volumeset_handler_idle(gpointer data)
+volumeset_handler_idle                  (gpointer data)
 {
         gint vol = GPOINTER_TO_INT(data);
-        gdk_threads_enter();
         controller_set_volume(vol);
-        gdk_threads_leave();
         return FALSE;
 }
 
 static gboolean
-requeststatus_handler_idle(gpointer data)
+requeststatus_handler_idle              (gpointer data)
 {
         LastfmTrack *current_track = NULL;
 
         current_track = controller_get_current_track();
-        gdk_threads_enter();
         lastfm_dbus_notify_playback(current_track);
-        gdk_threads_leave();
 
         return FALSE;
 }
@@ -124,7 +129,7 @@ requeststatus_handler_idle(gpointer data)
 #ifdef HAVE_GSD_MEDIA_PLAYER_KEYS
 
 static gboolean
-gsd_mp_keys_handler_idle(gpointer data)
+gsd_mp_keys_handler_idle                (gpointer data)
 {
         g_return_val_if_fail (data != NULL, FALSE);
 
@@ -141,9 +146,7 @@ gsd_mp_keys_handler_idle(gpointer data)
         }
 
         if (key_handler) {
-                gdk_threads_enter();
                 key_handler ();
-                gdk_threads_leave();
         }
 
         /* Free passed memory */
@@ -153,7 +156,7 @@ gsd_mp_keys_handler_idle(gpointer data)
 }
 
 static void
-grab_media_player_keys(void)
+grab_media_player_keys                  (void)
 {
         DBusMessage *dbus_msg = NULL;
         gchar *app_name = g_strdup (APP_NAME);
@@ -177,7 +180,7 @@ grab_media_player_keys(void)
 }
 
 static void
-release_media_player_keys(void)
+release_media_player_keys               (void)
 {
         DBusMessage *dbus_msg = NULL;
         gchar *app_name = g_strdup (APP_NAME);
@@ -201,16 +204,16 @@ release_media_player_keys(void)
 #endif /* HAVE_GSD_MEDIA_PLAYER_KEYS */
 
 static gboolean
-closeapp_handler_idle(gpointer data)
+closeapp_handler_idle                   (gpointer data)
 {
-        gdk_threads_enter();
         controller_quit_app();
-        gdk_threads_leave();
         return FALSE;
 }
 
 static void
-send_message(char *message, int first_type, ...)
+send_message                            (char *message,
+                                         int   first_type,
+                                         ...)
 {
         DBusMessage *dbus_msg = NULL;
         va_list ap;
@@ -230,7 +233,7 @@ send_message(char *message, int first_type, ...)
 }
 
 void
-lastfm_dbus_notify_playback (LastfmTrack *track)
+lastfm_dbus_notify_playback             (LastfmTrack *track)
 {
         const char *param = NULL;
 
@@ -254,7 +257,7 @@ lastfm_dbus_notify_playback (LastfmTrack *track)
 }
 
 void
-lastfm_dbus_notify_started(void)
+lastfm_dbus_notify_started              (void)
 {
         const char *param = APP_DBUS_SIGNAL_NOTIFY_STARTED;
 
@@ -265,7 +268,7 @@ lastfm_dbus_notify_started(void)
 }
 
 void
-lastfm_dbus_notify_closing(void)
+lastfm_dbus_notify_closing              (void)
 {
         const char *param = APP_DBUS_SIGNAL_NOTIFY_CLOSING;
 
@@ -276,7 +279,7 @@ lastfm_dbus_notify_closing(void)
 }
 
 static gboolean
-method_is_interactive (DBusMessage *message)
+method_is_interactive                   (DBusMessage *message)
 {
         gboolean interactive = FALSE;
         DBusMessageIter iter;
@@ -290,7 +293,7 @@ method_is_interactive (DBusMessage *message)
 }
 
 void
-lastfm_dbus_play_radio_url (const char *url)
+lastfm_dbus_play_radio_url              (const char *url)
 {
         DBusMessage *dbus_msg = NULL;
         dbus_msg = dbus_message_new_method_call (APP_DBUS_SERVICE,
@@ -308,8 +311,9 @@ lastfm_dbus_play_radio_url (const char *url)
 }
 
 static DBusHandlerResult
-dbus_req_handler(DBusConnection *connection, DBusMessage *message,
-                 gpointer user_data)
+dbus_req_handler                        (DBusConnection *connection,
+                                         DBusMessage    *message,
+                                         gpointer        user_data)
 {
         DBusHandlerResult result = DBUS_HANDLER_RESULT_HANDLED;
 
@@ -321,35 +325,37 @@ dbus_req_handler(DBusConnection *connection, DBusMessage *message,
                                       DBUS_TYPE_STRING,
                                       &url,
                                       DBUS_TYPE_INVALID);
-                g_idle_add(playurl_handler_idle, g_strdup(url));
+                gdk_threads_add_idle (playurl_handler_idle, g_strdup(url));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_PLAY)) {
-                g_idle_add(play_handler_idle, NULL);
+                gdk_threads_add_idle (play_handler_idle, NULL);
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_STOP)) {
-                g_idle_add(stop_handler_idle, NULL);
+                gdk_threads_add_idle (stop_handler_idle, NULL);
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_SKIP)) {
-                g_idle_add(skip_handler_idle, NULL);
+                gdk_threads_add_idle (skip_handler_idle, NULL);
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_LOVETRACK)) {
                 gboolean interactive = method_is_interactive (message);
-                g_idle_add (lovetrack_handler_idle,
-                            GINT_TO_POINTER (interactive));
+                gdk_threads_add_idle (lovetrack_handler_idle,
+                                      GINT_TO_POINTER (interactive));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_BANTRACK)) {
                 gboolean interactive = method_is_interactive (message);
-                g_idle_add (bantrack_handler_idle,
-                            GINT_TO_POINTER (interactive));
+                gdk_threads_add_idle (bantrack_handler_idle,
+                                      GINT_TO_POINTER (interactive));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_SHOWWINDOW)) {
-                g_idle_add(showwindow_handler_idle, GINT_TO_POINTER(TRUE));
+                gdk_threads_add_idle (showwindow_handler_idle,
+                                      GINT_TO_POINTER(TRUE));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_HIDEWINDOW)) {
-                g_idle_add(showwindow_handler_idle, GINT_TO_POINTER(FALSE));
+                gdk_threads_add_idle (showwindow_handler_idle,
+                                      GINT_TO_POINTER(FALSE));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                 APP_DBUS_METHOD_CLOSEAPP)) {
-                g_idle_add(closeapp_handler_idle, NULL);
+                gdk_threads_add_idle (closeapp_handler_idle, NULL);
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_VOLUMEUP)) {
                 guint32 inc;
@@ -358,8 +364,8 @@ dbus_req_handler(DBusConnection *connection, DBusMessage *message,
                 if (inc == G_MAXUINT32) {
                         inc = 5;
                 }
-                g_idle_add (volumechange_handler_idle,
-                            GINT_TO_POINTER ((gint) inc));
+                gdk_threads_add_idle (volumechange_handler_idle,
+                                      GINT_TO_POINTER ((gint) inc));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_VOLUMEDOWN)) {
                 guint32 inc;
@@ -368,26 +374,27 @@ dbus_req_handler(DBusConnection *connection, DBusMessage *message,
                 if (inc == G_MAXUINT32) {
                         inc = 5;
                 }
-                g_idle_add (volumechange_handler_idle,
-                            GINT_TO_POINTER ((gint) -inc));
+                gdk_threads_add_idle (volumechange_handler_idle,
+                                      GINT_TO_POINTER ((gint) -inc));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_SETVOLUME)) {
                 guint32 vol;
                 dbus_message_get_args(message, NULL, DBUS_TYPE_UINT32,
                                       &vol, DBUS_TYPE_INVALID);
                 if (vol != G_MAXUINT32) {
-                        g_idle_add (volumeset_handler_idle,
-                                    GINT_TO_POINTER ((gint) vol));
+                        gdk_threads_add_idle (volumeset_handler_idle,
+                                              GINT_TO_POINTER ((gint) vol));
                 } else {
                         g_debug ("No parameter received for "
                                  APP_DBUS_METHOD_SETVOLUME);
                 }
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_TOPAPP)) {
-                g_idle_add(showwindow_handler_idle, GINT_TO_POINTER(TRUE));
+                gdk_threads_add_idle (showwindow_handler_idle,
+                                      GINT_TO_POINTER(TRUE));
         } else if (dbus_message_is_method_call(message, APP_DBUS_IFACE,
                                                APP_DBUS_METHOD_REQUEST_STATUS)) {
-                g_idle_add(requeststatus_handler_idle, NULL);
+                gdk_threads_add_idle (requeststatus_handler_idle, NULL);
         } else {
                 result = DBUS_HANDLER_RESULT_NOT_YET_HANDLED;
         }
@@ -406,8 +413,8 @@ dbus_req_handler(DBusConnection *connection, DBusMessage *message,
 
                 if (app_name != NULL && key_pressed != NULL &&
                     g_str_equal (app_name, APP_NAME)) {
-                        g_idle_add(gsd_mp_keys_handler_idle,
-                                   g_strdup (key_pressed));
+                        gdk_threads_add_idle (gsd_mp_keys_handler_idle,
+                                              g_strdup (key_pressed));
                 }
                 result = DBUS_HANDLER_RESULT_HANDLED;
         }
@@ -425,10 +432,11 @@ dbus_req_handler(DBusConnection *connection, DBusMessage *message,
 }
 
 DbusInitReturnCode
-lastfm_dbus_init(void)
+lastfm_dbus_init                        (VglController *controller)
 {
         int result;
 
+        g_return_val_if_fail (VGL_IS_CONTROLLER (controller), DBUS_INIT_ERROR);
         g_debug("Initializing D-Bus...");
 
         /* Get D-Bus connection */
@@ -482,11 +490,18 @@ lastfm_dbus_init(void)
                 return DBUS_INIT_ALREADY_RUNNING;
         }
 
+        g_signal_connect (controller, "player-stopped",
+                          G_CALLBACK (player_stopped_cb), NULL);
+        g_signal_connect (controller, "track-started",
+                          G_CALLBACK (track_started_cb), NULL);
+        g_object_weak_ref (G_OBJECT (controller),
+                           controller_destroyed_cb, NULL);
+
         return DBUS_INIT_OK;
 }
 
 void
-lastfm_dbus_close(void)
+lastfm_dbus_close                       (void)
 {
         /* Remove filter, if added */
         if (dbus_filter_added) {
@@ -509,5 +524,6 @@ lastfm_dbus_close(void)
         /* Unref the D-bus connection */
         if (dbus_connection) {
                 dbus_connection_unref (dbus_connection);
+                dbus_connection = NULL;
         }
 }
