@@ -1,7 +1,7 @@
 /*
  * lastfm-ws.c -- Last.fm Web Services v2.0
  *
- * Copyright (C) 2009 Igalia, S.L.
+ * Copyright (C) 2009-2011 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3
@@ -476,6 +476,7 @@ lastfm_ws_radio_tune                    (LastfmWsSession *session,
 LastfmPls *
 lastfm_ws_radio_get_playlist            (const LastfmWsSession *session,
                                          gboolean               discovery,
+                                         gboolean               low_bitrate,
                                          gboolean               scrobbling)
 {
         LastfmPls *pls = NULL;
@@ -506,6 +507,7 @@ lastfm_ws_radio_get_playlist            (const LastfmWsSession *session,
                                 "discovery", discovery ? "1" : "0",
                                 "rtp", scrobbling ? "1" : "0",
                                 "sk", session->key,
+                                low_bitrate ? "bitrate" : NULL, "64",
                                 NULL);
 
         if (doc != NULL) {
@@ -520,7 +522,7 @@ lastfm_ws_radio_get_playlist            (const LastfmWsSession *session,
                 if (session->v1sess && !session->subscriber) {
                         session->srv->old_str_api = TRUE;
                         return lastfm_ws_radio_get_playlist (
-                                session, discovery, scrobbling);
+                                session, discovery, low_bitrate, scrobbling);
                 }
         }
 
@@ -723,7 +725,7 @@ lastfm_ws_old_get_album_tags            (const LastfmTrack     *track,
         g_free (url);
         g_free (buffer);
 
-        return FALSE;
+        return found;
 }
 #endif /* VGL_USE_NEW_ALBUM_TAGS_API */
 
