@@ -1,7 +1,7 @@
 /*
  * uimisc-gtk.c -- GTK+ UI functions
  *
- * Copyright (C) 2007-2010 Igalia, S.L.
+ * Copyright (C) 2007-2011 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
@@ -19,9 +19,12 @@ typedef struct {
         GtkDialog *dialog;
         GtkNotebook *nb;
         GtkEntry *user, *pw, *proxy, *dlentry;
-        GtkComboBox *srvcombo;
-        GtkWidget *dlbutton, *scrobble, *discovery, *useproxy;
+        GtkComboBoxText *srvcombo;
+        GtkWidget *dlbutton, *scrobble, *discovery, *useproxy, *lowbitrate;
         GtkWidget *dlfreetracks;
+#ifdef HAVE_LIBPROXY
+        GtkWidget *sysproxy;
+#endif
         GtkWidget *disableconfdiags;
         GtkWidget *helpbtn;
 #ifdef SET_IM_STATUS
@@ -79,7 +82,8 @@ ui_create_combo_box_entry               (const GList *elems)
         GtkTreeModel *model;
 
         model = ui_create_options_list (elems);
-        combo = gtk_combo_box_entry_new_with_model (model, 0);
+        combo = gtk_combo_box_text_new_with_entry ();
+        gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL(model));
 
         completion = gtk_entry_completion_new ();
         gtk_entry_completion_set_model (completion, model);
@@ -106,6 +110,7 @@ ui_usertag_dialog                       (GtkWindow    *parent,
         GtkDialog *dialog;
         GtkWidget *userlabel, *taglabel;
         GtkWidget *usercombo, *tagentry;
+        GtkEntry *comboentry;
         GtkTable *table;
 
         g_return_if_fail (parent == NULL || GTK_IS_WINDOW (parent));
@@ -115,6 +120,7 @@ ui_usertag_dialog                       (GtkWindow    *parent,
         userlabel = gtk_label_new (_("Username:"));
         taglabel = gtk_label_new (_("Tag:"));
         usercombo = ui_create_combo_box_entry (userlist);
+        comboentry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (usercombo)));
         tagentry = gtk_entry_new ();
         table = GTK_TABLE (gtk_table_new (2, 2, FALSE));
 
@@ -122,10 +128,10 @@ ui_usertag_dialog                       (GtkWindow    *parent,
         gtk_table_attach_defaults (table, taglabel, 0, 1, 1, 2);
         gtk_table_attach_defaults (table, usercombo, 1, 2, 0, 1);
         gtk_table_attach_defaults (table, tagentry, 1, 2, 1, 2);
-        gtk_container_add (GTK_CONTAINER (dialog->vbox), GTK_WIDGET (table));
+        gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area(dialog)),
+                           GTK_WIDGET (table));
 
-        gtk_entry_set_activates_default (
-                GTK_ENTRY (GTK_BIN (usercombo)->child), TRUE);
+        gtk_entry_set_activates_default (comboentry, TRUE);
         gtk_entry_set_activates_default (GTK_ENTRY (tagentry), TRUE);
         gtk_misc_set_alignment (GTK_MISC (userlabel), 0, 0.5);
         gtk_misc_set_alignment (GTK_MISC (taglabel), 0, 0.5);
@@ -134,8 +140,7 @@ ui_usertag_dialog                       (GtkWindow    *parent,
         gtk_container_set_border_width (GTK_CONTAINER (table), 10);
 
         if (*user != NULL) {
-                gtk_entry_set_text (
-                        GTK_ENTRY (GTK_BIN (usercombo)->child), *user);
+                gtk_entry_set_text (comboentry, *user);
                 g_free (*user);
         }
         if (*tag != NULL) {
@@ -147,8 +152,7 @@ ui_usertag_dialog                       (GtkWindow    *parent,
         gtk_widget_show_all (GTK_WIDGET (dialog));
 
         if (gtk_dialog_run (dialog) == GTK_RESPONSE_ACCEPT) {
-                GtkEntry *entry = GTK_ENTRY (GTK_BIN (usercombo)->child);
-                *user = g_strstrip (g_strdup (gtk_entry_get_text (entry)));
+                *user = g_strstrip (g_strdup (gtk_entry_get_text(comboentry)));
                 *tag = g_strstrip (g_strdup (gtk_entry_get_text (
                                                      GTK_ENTRY (tagentry))));
         }
@@ -174,23 +178,23 @@ change_dir_selected                     (GtkWidget *widget,
         }
 }
 
-static GtkComboBox *
+static GtkComboBoxText *
 usercfg_create_server_combobox          (VglUserCfg *cfg)
 {
-        GtkComboBox *combo;
+        GtkComboBoxText *combo;
         const GList *srvlist, *iter;
         int i;
 
         g_return_val_if_fail (cfg != NULL, NULL);
 
-        combo = GTK_COMBO_BOX (gtk_combo_box_new_text ());
+        combo = GTK_COMBO_BOX_TEXT (gtk_combo_box_text_new ());
 
         srvlist = vgl_server_list_get ();
         for (iter = srvlist, i = 0; iter != NULL; iter = iter->next, i++) {
                 const VglServer *srv = iter->data;
-                gtk_combo_box_append_text (combo, srv->name);
+                gtk_combo_box_text_append_text (combo, srv->name);
                 if (srv == cfg->server) {
-                        gtk_combo_box_set_active (combo, i);
+                        gtk_combo_box_set_active (GTK_COMBO_BOX (combo), i);
                 }
 
         }
@@ -296,21 +300,37 @@ usercfg_add_account_settings            (usercfgwin *win,
         g_object_set_data(G_OBJECT(table), "help-message", (gpointer) help);
 }
 
+#ifdef HAVE_LIBPROXY
+static void
+usercfg_sysproxy_toggled                (GtkToggleButton *button,
+                                         usercfgwin      *win)
+{
+        gtk_widget_set_sensitive (GTK_WIDGET (win->proxy),
+                                  !gtk_toggle_button_get_active (button));
+}
+#endif /* HAVE_LIBPROXY */
+
 static void
 usercfg_add_connection_settings         (usercfgwin *win,
                                          VglUserCfg *cfg)
 {
         g_return_if_fail(win != NULL && GTK_IS_NOTEBOOK(win->nb));
         GtkTable *table;
-        GtkWidget *useproxylabel, *proxylabel;
-        const char *help;
+        GtkWidget *useproxylabel, *proxylabel, *lowbitratelabel;
+        GString *help = g_string_sized_new (100);
+        gint i;
+#ifdef HAVE_LIBPROXY
+        GtkWidget *sysproxylabel;
+#endif
 
         /* Create widgets */
-        table = GTK_TABLE (gtk_table_new (2, 2, FALSE));
-        useproxylabel = gtk_label_new(_("Use HTTP proxy"));
+        table = GTK_TABLE (gtk_table_new (3, 2, FALSE));
+        useproxylabel = gtk_label_new(_("Use proxy"));
         proxylabel = gtk_label_new(_("Proxy address:"));
+        lowbitratelabel = gtk_label_new(_("Low bitrate stream"));
         win->proxy = GTK_ENTRY(gtk_entry_new());
         win->useproxy = gtk_check_button_new();
+        win->lowbitrate = gtk_check_button_new();
 
         /* Set widget properties */
         gtk_entry_set_activates_default(win->proxy, TRUE);
@@ -319,21 +339,59 @@ usercfg_add_connection_settings         (usercfgwin *win,
         gtk_entry_set_text(win->proxy, cfg->http_proxy);
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(win->useproxy),
                                      cfg->use_proxy);
+        gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(win->lowbitrate),
+                                     cfg->low_bitrate);
 
         /* Pack widgets */
-        gtk_table_attach(table, useproxylabel, 0, 1, 0, 1, 0, 0, 5, 5);
-        gtk_table_attach(table, proxylabel, 0, 1, 1, 2, 0, 0, 5, 5);
-        gtk_table_attach(table, win->useproxy, 1, 2, 0, 1, 0, 0, 5, 5);
-        gtk_table_attach(table, GTK_WIDGET(win->proxy), 1, 2, 1, 2,
-                         GTK_EXPAND | GTK_FILL, 0, 5, 5);
+        i = 0;
+        gtk_table_attach (table, useproxylabel, 0, 1, i, i+1, 0, 0, 5, 5);
+        gtk_table_attach (table, win->useproxy, 1, 2, i, i+1, 0, 0, 5, 5);
+        i++;
+
+        g_string_append (help,
+                         _("* Use proxy:\nEnable this to use a proxy.\n\n"));
+
+#ifdef HAVE_LIBPROXY
+        sysproxylabel = gtk_label_new (_("Use system-wide proxy"));
+        win->sysproxy = gtk_check_button_new ();
+
+        g_signal_connect (win->sysproxy, "toggled",
+                          G_CALLBACK (usercfg_sysproxy_toggled), win);
+
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (win->sysproxy),
+                                      cfg->use_system_proxy);
+
+        gtk_table_attach (table, sysproxylabel, 0, 1, i, i+1, 0, 0, 5, 5);
+        gtk_table_attach (table, win->sysproxy, 1, 2, i, i+1, 0, 0, 5, 5);
+        i++;
+
+        g_string_append (help,
+                         _("* Use system-wide proxy:\nUse the system-wide "
+                           "proxy configuration.\n\n"));
+#endif /* HAVE_LIBPROXY */
+
+        gtk_table_attach (table, proxylabel, 0, 1, i, i+1, 0, 0, 5, 5);
+        gtk_table_attach (table, lowbitratelabel, 0, 1, i+1, i+2, 0, 0, 5, 5);
+        gtk_table_attach (table, GTK_WIDGET (win->proxy), 1, 2, i, i+1,
+                          GTK_EXPAND | GTK_FILL, 0, 5, 5);
+        gtk_table_attach (table, win->lowbitrate, 1, 2, i+1, i+2, 0, 0, 5, 5);
+
         gtk_notebook_append_page(win->nb, GTK_WIDGET(table),
                                  gtk_label_new(_("Connection")));
 
         /* Set help */
-        help = _("* Use HTTP proxy:\nEnable this to use an HTTP proxy.\n\n"
-                 "* Proxy address:\nuser:password@hostname:port\n"
-                 "Only the hostname (can be an IP address) is required.");
-        g_object_set_data(G_OBJECT(table), "help-message", (gpointer) help);
+        g_string_append (
+                help,
+                _("* Proxy address:\n"
+                  "[protocol://]user:password@hostname:port\n"
+                  "Only the hostname (can be an IP address) is required.\n"
+                  "Supported protocols: http, socks4, socks5.\n\n"
+                  "* Low bitrate stream:\n"
+                  "Try to get a low bitrate stream from the server\n"
+                  "to save bandwidth."));
+
+        g_object_set_data_full (G_OBJECT (table), "help-message",
+                                g_string_free (help, FALSE), g_free);
 }
 
 static void
@@ -533,10 +591,11 @@ ui_usercfg_window                       (GtkWindow   *parent,
         win.dialog = ui_base_dialog(parent, _("User settings"));
         win.nb = GTK_NOTEBOOK(gtk_notebook_new());
         win.helpbtn = gtk_button_new_from_stock(GTK_STOCK_HELP);
-        gtk_box_pack_start(GTK_BOX(win.dialog->action_area), win.helpbtn,
-                           FALSE, FALSE, 0);
+        gtk_box_pack_start (GTK_BOX (gtk_dialog_get_action_area (win.dialog)),
+                            win.helpbtn, FALSE, FALSE, 0);
         gtk_button_box_set_child_secondary (
-                GTK_BUTTON_BOX (win.dialog->action_area), win.helpbtn, TRUE);
+                GTK_BUTTON_BOX (gtk_dialog_get_action_area (win.dialog)),
+                win.helpbtn, TRUE);
 
         usercfg_add_account_settings(&win, *cfg);
         usercfg_add_connection_settings(&win, *cfg);
@@ -544,8 +603,8 @@ ui_usercfg_window                       (GtkWindow   *parent,
         usercfg_add_imstatus_settings(&win, *cfg);
         usercfg_add_misc_settings(&win, *cfg);
 
-        gtk_box_pack_start(GTK_BOX((win.dialog)->vbox), GTK_WIDGET(win.nb),
-                           FALSE, FALSE, 10);
+        gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (win.dialog)),
+                            GTK_WIDGET (win.nb), FALSE, FALSE, 10);
 
         windata = g_slice_new(change_dir_selected_data);
         windata->win = GTK_WINDOW(win.dialog);
@@ -564,13 +623,19 @@ ui_usercfg_window                       (GtkWindow   *parent,
                 vgl_user_cfg_set_download_dir(*cfg,
                                                 gtk_entry_get_text(win.dlentry));
                 vgl_user_cfg_set_server_name(
-                        *cfg, gtk_combo_box_get_active_text (win.srvcombo));
+                        *cfg, gtk_combo_box_text_get_active_text (win.srvcombo));
                 (*cfg)->enable_scrobbling = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.scrobble));
                 (*cfg)->discovery_mode = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.discovery));
                 (*cfg)->use_proxy = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.useproxy));
+#ifdef HAVE_LIBPROXY
+                (*cfg)->use_system_proxy = gtk_toggle_button_get_active(
+                        GTK_TOGGLE_BUTTON(win.sysproxy));
+#endif
+                (*cfg)->low_bitrate = gtk_toggle_button_get_active(
+                        GTK_TOGGLE_BUTTON(win.lowbitrate));
                 (*cfg)->autodl_free_tracks = gtk_toggle_button_get_active(
                         GTK_TOGGLE_BUTTON(win.dlfreetracks));
 #ifdef SET_IM_STATUS
@@ -615,21 +680,23 @@ ui_input_dialog_with_list               (GtkWindow   *parent,
         GtkDialog *dialog;
         GtkWidget *label;
         GtkWidget *combo;
+        GtkEntry *entry;
+        GtkBox *vbox;
         char *retvalue = NULL;
         dialog = ui_base_dialog(parent, title);
+        vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
         label = gtk_label_new(text);
         combo = ui_create_combo_box_entry(elems);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), label, FALSE, FALSE, 10);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), combo, FALSE, FALSE, 10);
+        entry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo)));
+        gtk_box_pack_start (vbox, label, FALSE, FALSE, 10);
+        gtk_box_pack_start (vbox, combo, FALSE, FALSE, 10);
         gtk_widget_show_all(GTK_WIDGET(dialog));
         if (value != NULL) {
-                gtk_entry_set_text(GTK_ENTRY(GTK_BIN(combo)->child), value);
+                gtk_entry_set_text (entry, value);
         }
-        gtk_entry_set_activates_default(GTK_ENTRY(GTK_BIN(combo)->child),
-                                        TRUE);
+        gtk_entry_set_activates_default (entry, TRUE);
         if (gtk_dialog_run(dialog) == GTK_RESPONSE_ACCEPT) {
-                GtkEntry *entry = GTK_ENTRY(GTK_BIN(combo)->child);
-                retvalue = g_strstrip(g_strdup(gtk_entry_get_text(entry)));
+                retvalue = g_strstrip (g_strdup (gtk_entry_get_text (entry)));
         }
         gtk_widget_destroy(GTK_WIDGET(dialog));
         return retvalue;
@@ -708,7 +775,7 @@ recommwin_run                           (GtkWindow             *parent,
         g_return_val_if_fail(user && message && track && type, FALSE);
         gboolean retval = FALSE;
         GtkDialog *dialog;
-        GtkBox *selbox, *userbox;
+        GtkBox *selbox, *userbox, *vbox;
         GtkWidget *sellabel;
         GtkComboBox *selcombo;
         GtkWidget *userlabel, *usercombo;
@@ -718,8 +785,9 @@ recommwin_run                           (GtkWindow             *parent,
 
         /* Dialog and basic settings */
         dialog = ui_base_dialog(parent, _("Send a recommendation"));
-        gtk_box_set_homogeneous(GTK_BOX(dialog->vbox), FALSE);
-        gtk_box_set_spacing(GTK_BOX(dialog->vbox), 5);
+        vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
+        gtk_box_set_homogeneous (vbox, FALSE);
+        gtk_box_set_spacing (vbox, 5);
 
         /* Combo to select what to recommend */
         selbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
@@ -748,8 +816,8 @@ recommwin_run                           (GtkWindow             *parent,
         userbox = GTK_BOX(gtk_hbox_new(FALSE, 5));
         userlabel = gtk_label_new(_("Send recommendation to"));
         usercombo = ui_create_combo_box_entry(friends);
-        gtk_entry_set_activates_default(GTK_ENTRY(GTK_BIN(usercombo)->child),
-                                        TRUE);
+        gtk_entry_set_activates_default (
+                GTK_ENTRY (gtk_bin_get_child (GTK_BIN (usercombo))), TRUE);
         gtk_box_pack_start(userbox, userlabel, FALSE, FALSE, 0);
         gtk_box_pack_start(userbox, usercombo, TRUE, TRUE, 0);
 
@@ -768,18 +836,15 @@ recommwin_run                           (GtkWindow             *parent,
         gtk_container_add(GTK_CONTAINER(sw), GTK_WIDGET(textview));
 
         /* Widget packing */
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), GTK_WIDGET(selbox),
-                           FALSE, FALSE, 0);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), GTK_WIDGET(userbox),
-                           FALSE, FALSE, 0);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), GTK_WIDGET(textlabel),
-                           TRUE, TRUE, 0);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), GTK_WIDGET(textframe),
-                           TRUE, TRUE, 0);
+        gtk_box_pack_start (vbox, GTK_WIDGET (selbox), FALSE, FALSE, 0);
+        gtk_box_pack_start (vbox, GTK_WIDGET (userbox), FALSE, FALSE, 0);
+        gtk_box_pack_start (vbox, GTK_WIDGET (textlabel), TRUE, TRUE, 0);
+        gtk_box_pack_start (vbox, GTK_WIDGET (textframe), TRUE, TRUE, 0);
 
         gtk_widget_show_all(GTK_WIDGET(dialog));
         if (gtk_dialog_run(dialog) == GTK_RESPONSE_ACCEPT) {
-                GtkEntry *entry = GTK_ENTRY(GTK_BIN(usercombo)->child);
+                GtkEntry *entry = GTK_ENTRY (
+                        gtk_bin_get_child (GTK_BIN (usercombo)));
                 GtkTextIter start, end;
                 GtkTextBuffer *buf = gtk_text_view_get_buffer(textview);
                 gtk_text_buffer_get_bounds(buf, &start, &end);
@@ -951,11 +1016,12 @@ tagwin_tagcombo_changed                 (GtkComboBox *combo,
                                          gpointer     data)
 {
         if (gtk_combo_box_get_active(combo) == -1 ||
-            !GTK_WIDGET_IS_SENSITIVE(combo)) return;
+            !gtk_widget_is_sensitive(GTK_WIDGET (combo))) return;
         tagwin *w = (tagwin *) data;
         g_return_if_fail(w != NULL && w->entry != NULL);
         char *current = g_strchomp(g_strdup(gtk_entry_get_text(w->entry)));
-        const char *selected = gtk_combo_box_get_active_text(combo);
+        const char *selected =
+                gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(combo));
         char *new;
         if (current[0] == '\0') {
                 new = g_strdup(selected);
@@ -992,6 +1058,7 @@ tagwin_run                              (GtkWindow             *parent,
         GtkTreeModel *usermodel, *nonemodel, *retrmodel;
         GtkCellRenderer *userrender, *globalrender;
         GtkDialog *dialog;
+        GtkBox *vbox;
         GList *nonelist;
         GtkTable *table;
         GtkWidget *alig;
@@ -1006,8 +1073,9 @@ tagwin_run                              (GtkWindow             *parent,
 
         /* Dialog and basic settings */
         dialog = ui_base_dialog(parent, _("Tagging"));
-        gtk_box_set_homogeneous(GTK_BOX(dialog->vbox), FALSE);
-        gtk_box_set_spacing(GTK_BOX(dialog->vbox), 5);
+        vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
+        gtk_box_set_homogeneous (vbox, FALSE);
+        gtk_box_set_spacing (vbox, 5);
 
         /* Combo to select what to tag */
         sellabel = gtk_label_new(_("Tag this"));
@@ -1043,8 +1111,12 @@ tagwin_run                              (GtkWindow             *parent,
         } else {
                 usermodel = g_object_ref(nonemodel);
         }
-        usercombo = gtk_combo_box_new_with_model(usermodel);
-        globalcombo = gtk_combo_box_new_with_model(retrmodel);
+        usercombo = gtk_combo_box_text_new ();
+        gtk_combo_box_set_model (GTK_COMBO_BOX (usercombo), usermodel);
+        gtk_cell_layout_clear (GTK_CELL_LAYOUT (usercombo));
+        globalcombo = gtk_combo_box_text_new ();
+        gtk_combo_box_set_model (GTK_COMBO_BOX (globalcombo), retrmodel);
+        gtk_cell_layout_clear (GTK_CELL_LAYOUT (globalcombo));
         g_object_unref(G_OBJECT(usermodel));
         userrender = gtk_cell_renderer_text_new();
         globalrender = gtk_cell_renderer_text_new();
@@ -1069,8 +1141,7 @@ tagwin_run                              (GtkWindow             *parent,
         table = GTK_TABLE(gtk_table_new(4, 2, FALSE));
         gtk_table_set_row_spacings(table, 5);
         gtk_table_set_col_spacings(table, 20);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), GTK_WIDGET(table),
-                           TRUE, TRUE, 5);
+        gtk_box_pack_start (vbox, GTK_WIDGET(table), TRUE, TRUE, 5);
 
         alig = gtk_alignment_new(1, 0.5, 0, 0);
         gtk_container_add(GTK_CONTAINER(alig), sellabel);
