@@ -1,7 +1,7 @@
 /*
  * uimisc-hildon22.c -- Hildon 2.2 UI functions
  *
- * Copyright (C) 2010 Igalia, S.L.
+ * Copyright (C) 2010, 2011 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
@@ -13,6 +13,7 @@
 
 #include "uimisc.h"
 #include "util.h"
+#include "compat.h"
 
 static const char pidgin_name[] = "Pidgin";
 static const char gajim_name[] = "Gajim";
@@ -240,7 +241,8 @@ ui_usercfg_window                       (GtkWindow   *parent,
         GtkWidget *frame;
         GtkEntry *user, *pw, *proxy, *imtemplate;
         HildonButton *service, *dlbutton, *imbutton;
-        HildonCheckButton *scrob, *discov, *useproxy, *autodl, *nodiags;
+        HildonCheckButton *scrob, *discov, *useproxy;
+        HildonCheckButton *lowbitrate, *autodl, *nodiags;
         HildonTouchSelector *servicesel, *imsel;
         GtkBox *vbox, *hbox, *framebox;
         GtkSizeGroup *size_group;
@@ -339,6 +341,11 @@ ui_usercfg_window                       (GtkWindow   *parent,
         gtk_box_pack_start (hbox, GTK_WIDGET (proxy), TRUE, TRUE, 0);
         gtk_box_pack_start (vbox, GTK_WIDGET (hbox), FALSE, FALSE, 0);
 
+        /* Low bitrate stream */
+        lowbitrate = HILDON_CHECK_BUTTON (hildon_check_button_new (FINGER_SIZE));
+        gtk_button_set_label (GTK_BUTTON (lowbitrate), _("Low bitrate stream"));
+        gtk_box_pack_start (vbox, GTK_WIDGET (lowbitrate), FALSE, FALSE, 0);
+
         /* Download frame */
         frame = gtk_frame_new (_("Download"));
         vbox = GTK_BOX (gtk_vbox_new (TRUE, 0));
@@ -407,7 +414,9 @@ ui_usercfg_window                       (GtkWindow   *parent,
         /* Pack everything else */
         hildon_pannable_area_add_with_viewport (HILDON_PANNABLE_AREA (panarea),
                                                 GTK_WIDGET (framebox));
-        gtk_container_add (GTK_CONTAINER (GTK_DIALOG (d)->vbox), panarea);
+        gtk_container_add (
+                GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (d))),
+                panarea);
 
         /* Connect signals */
         win.user = user;
@@ -430,6 +439,7 @@ ui_usercfg_window                       (GtkWindow   *parent,
         hildon_check_button_set_active (scrob, (*cfg)->enable_scrobbling);
         hildon_check_button_set_active (discov, (*cfg)->discovery_mode);
         hildon_check_button_set_active (useproxy, (*cfg)->use_proxy);
+        hildon_check_button_set_active (lowbitrate, (*cfg)->low_bitrate);
         hildon_check_button_set_active (autodl, (*cfg)->autodl_free_tracks);
         hildon_check_button_set_active (nodiags,
                                         (*cfg)->disable_confirm_dialogs);
@@ -451,6 +461,8 @@ ui_usercfg_window                       (GtkWindow   *parent,
                         hildon_check_button_get_active (discov);
                 (*cfg)->use_proxy =
                         hildon_check_button_get_active (useproxy);
+                (*cfg)->low_bitrate =
+                        hildon_check_button_get_active (lowbitrate);
                 (*cfg)->autodl_free_tracks =
                         hildon_check_button_get_active (autodl);
                 vgl_user_cfg_set_imstatus_template (
@@ -633,7 +645,7 @@ recommwin_run                           (GtkWindow             *parent,
         gboolean retval = FALSE;
         GtkDialog *dialog;
         GtkWidget *panarea;
-        GtkBox *vbox;
+        GtkBox *vbox, *dvbox;
         GtkWidget *selbutton;
         GtkWidget *userbutton;
         GtkWidget *textlabel;
@@ -643,8 +655,9 @@ recommwin_run                           (GtkWindow             *parent,
 
         /* Dialog and basic settings */
         dialog = ui_base_dialog (parent, _("Send a recommendation"));
-        gtk_box_set_homogeneous (GTK_BOX (dialog->vbox), FALSE);
-        gtk_box_set_spacing (GTK_BOX (dialog->vbox), 5);
+        dvbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
+        gtk_box_set_homogeneous (dvbox, FALSE);
+        gtk_box_set_spacing (dvbox, 5);
 
         /* Picker button to select what to recommend */
         selbutton = artist_track_album_button_new (
@@ -671,7 +684,7 @@ recommwin_run                           (GtkWindow             *parent,
         gtk_box_pack_start (vbox, GTK_WIDGET (userbutton), FALSE, FALSE, 0);
         gtk_box_pack_start (vbox, GTK_WIDGET (textlabel), TRUE, TRUE, 0);
         gtk_box_pack_start (vbox, GTK_WIDGET (textview), TRUE, TRUE, 0);
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), panarea, TRUE, TRUE, 0);
+        gtk_box_pack_start (dvbox, panarea, TRUE, TRUE, 0);
         hildon_pannable_area_add_with_viewport (
                 HILDON_PANNABLE_AREA (panarea), GTK_WIDGET (vbox));
 
@@ -944,6 +957,7 @@ tagwin_run                              (GtkWindow             *parent,
         GtkWidget *entrylabel, *entry, *userbutton, *globalbutton;
         HildonTouchSelector *sel;
         GtkDialog *dialog;
+        GtkBox *vbox;
 
         g_return_val_if_fail (ws_session && track && type &&
                               user && newtags, FALSE);
@@ -951,8 +965,9 @@ tagwin_run                              (GtkWindow             *parent,
         /* Dialog and basic settings */
         t = tagwin_create ();
         dialog = ui_base_dialog (parent, _("Tagging"));
-        gtk_box_set_homogeneous (GTK_BOX (dialog->vbox), FALSE);
-        gtk_box_set_spacing (GTK_BOX (dialog->vbox), 5);
+        vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
+        gtk_box_set_homogeneous (vbox, FALSE);
+        gtk_box_set_spacing (vbox, 5);
 
         /* Combo to select what to tag */
         selbutton = artist_track_album_button_new (_("Tag this"),track,*type);
@@ -982,12 +997,11 @@ tagwin_run                              (GtkWindow             *parent,
         }
 
         /* Widget packing */
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), selbutton, TRUE, TRUE, 5);
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), entrylabel, TRUE, TRUE, 5);
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), entry, TRUE, TRUE, 5);
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), userbutton, TRUE, TRUE, 5);
-        gtk_box_pack_start (GTK_BOX (dialog->vbox),
-                            globalbutton, TRUE, TRUE, 5);
+        gtk_box_pack_start (vbox, selbutton, TRUE, TRUE, 5);
+        gtk_box_pack_start (vbox, entrylabel, TRUE, TRUE, 5);
+        gtk_box_pack_start (vbox, entry, TRUE, TRUE, 5);
+        gtk_box_pack_start (vbox, userbutton, TRUE, TRUE, 5);
+        gtk_box_pack_start (vbox, globalbutton, TRUE, TRUE, 5);
 
         t->track = vgl_object_ref (track);
         t->ws_session = vgl_object_ref (ws_session);
