@@ -1,7 +1,7 @@
 /*
  * uimisc.c -- Misc UI-related functions
  *
- * Copyright (C) 2007-2010 Igalia, S.L.
+ * Copyright (C) 2007-2011 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
@@ -73,6 +73,7 @@ static const char license[] =
 "Public License along with Vagalume. If not, see\n"
 "http://www.gnu.org/licenses/\n";
 static const char translators_tpl[] =
+"%s (ca)\n* Carles Muñoz Gorriz <carlesmu@internautas.org>\n\n"
 "%s (de)\n* Stephan Reichholf <stephan@reichholf.net>\n"
          "* Oskar Welzl <mail@welzl.info>\n\n"
 "%s (es)\n* Oscar A. Mata T. <omata_mac@yahoo.com>\n"
@@ -168,9 +169,9 @@ void
 ui_about_dialog                         (GtkWindow *parent)
 {
         GdkPixbuf *logo = gdk_pixbuf_new_from_file (APP_ICON_BIG, NULL);
-        char *translators = g_strdup_printf (translators_tpl, _("German"),
-                                             _("Spanish"), _("Finnish"),
-                                             _("French"),
+        char *translators = g_strdup_printf (translators_tpl, _("Catalan"),
+                                             _("German"), _("Spanish"),
+                                             _("Finnish"), _("French"),
                                              _("Galician"), _("Italian"),
                                              _("Latvian"), _("Polish"),
                                              _("Portuguese"), _("Portuguese"),
@@ -221,7 +222,8 @@ ui_confirm_dialog                       (GtkWindow  *parent,
         gint response;
         GtkDialog *dialog = ui_base_dialog(parent, _("Confirmation"));
         GtkWidget *label = gtk_label_new(text);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), label, FALSE, FALSE, 10);
+        GtkBox *vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
+        gtk_box_pack_start (vbox, label, FALSE, FALSE, 10);
         gtk_widget_show_all(GTK_WIDGET(dialog));
         response = gtk_dialog_run(dialog);
         gtk_widget_destroy(GTK_WIDGET(dialog));
@@ -237,17 +239,18 @@ ui_input_dialog                         (GtkWindow  *parent,
         GtkDialog *dialog;
         GtkWidget *label;
         GtkEntry *entry;
+        GtkBox *vbox;
         char *retvalue = NULL;
         dialog = ui_base_dialog(parent, title);
+        vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
         label = gtk_label_new(text);
 #ifdef MAEMO5
         entry = GTK_ENTRY(hildon_entry_new(FINGER_SIZE));
 #else
         entry = GTK_ENTRY(gtk_entry_new());
 #endif
-        gtk_box_pack_start(GTK_BOX(dialog->vbox), label, FALSE, FALSE, 10);
-        gtk_box_pack_start(GTK_BOX(dialog->vbox),
-                           GTK_WIDGET(entry), FALSE, FALSE, 10);
+        gtk_box_pack_start (vbox, label, FALSE, FALSE, 10);
+        gtk_box_pack_start (vbox, GTK_WIDGET (entry), FALSE, FALSE, 10);
         if (value != NULL) gtk_entry_set_text(entry, value);
         gtk_entry_set_activates_default(entry, TRUE);
         gtk_widget_show_all(GTK_WIDGET(dialog));
@@ -284,7 +287,7 @@ ui_edit_bookmark_dialog                 (GtkWindow  *parent,
         if (*name != NULL) gtk_entry_set_text(nameentry, *name);
         if (*url != NULL) gtk_entry_set_text(urlentry, *url);
 
-        vbox = GTK_BOX (dialog->vbox);
+        vbox = GTK_BOX (gtk_dialog_get_content_area (dialog));
         gtk_box_pack_start(vbox, namelabel, FALSE, FALSE, 4);
         gtk_box_pack_start(vbox, GTK_WIDGET(nameentry), FALSE, FALSE, 4);
         gtk_box_pack_start(vbox, urllabel, FALSE, FALSE, 4);
@@ -498,9 +501,10 @@ ui_stop_after_dialog                    (GtkWindow     *parent,
         }
 
         /* Create combo box */
-        combo = gtk_combo_box_entry_new_with_model (GTK_TREE_MODEL (model), 0);
+        combo = gtk_combo_box_text_new_with_entry ();
+        gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL(model));
         g_object_unref (model);
-        entry = GTK_ENTRY (GTK_BIN (combo)->child);
+        entry = GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo)));
         gtk_entry_set_width_chars (entry, 4);
 #ifdef MAEMO
         hildon_gtk_entry_set_input_mode (entry, HILDON_GTK_INPUT_MODE_NUMERIC);
@@ -535,7 +539,8 @@ ui_stop_after_dialog                    (GtkWindow     *parent,
         gtk_box_pack_start (GTK_BOX (vbox), radio2, FALSE, FALSE, 0);
         gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
         gtk_container_add (GTK_CONTAINER (alignment), vbox);
-        gtk_box_pack_start (GTK_BOX (dialog->vbox), alignment, TRUE, TRUE, 10);
+        gtk_box_pack_start (GTK_BOX (gtk_dialog_get_content_area (dialog)),
+                            alignment, TRUE, TRUE, 10);
 
         /* Fill StopAfterDialog struct */
         win.dialog = dialog;
