@@ -1,7 +1,7 @@
 /*
  * userconfig.c -- Read and write the user configuration file
  *
- * Copyright (C) 2007-2010 Igalia, S.L.
+ * Copyright (C) 2007-2011 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
@@ -185,6 +185,8 @@ vgl_user_cfg_new                        (void)
         cfg->server = vgl_server_get_default ();
         if (cfg->server) vgl_object_ref (cfg->server);
         cfg->use_proxy = FALSE;
+        cfg->use_system_proxy = FALSE;
+        cfg->low_bitrate = FALSE;
         cfg->enable_scrobbling = TRUE;
         cfg->discovery_mode = FALSE;
         cfg->im_pidgin = FALSE;
@@ -353,6 +355,9 @@ vgl_user_cfg_read                       (void)
                         g_free (str);
                 }
                 xml_get_bool (doc, node, "use-proxy", &(cfg->use_proxy));
+                xml_get_bool (doc, node, "use-system-proxy",
+                              &(cfg->use_system_proxy));
+                xml_get_bool (doc, node, "low-bitrate", &(cfg->low_bitrate));
                 xml_get_bool (doc, node, "discovery-mode",
                               &(cfg->discovery_mode));
                 xml_get_bool (doc, node, "enable-scrobbling",
@@ -390,7 +395,7 @@ vgl_user_cfg_write                      (VglUserCfg *cfg)
         doc = xmlNewDoc ((xmlChar *) "1.0");
         root = xmlNewNode (NULL, (xmlChar *) "config");
         xmlSetProp (root, (xmlChar *) "version", (xmlChar *) "1");
-        xmlSetProp (root, (xmlChar *) "revision", (xmlChar *) "3");
+        xmlSetProp (root, (xmlChar *) "revision", (xmlChar *) "5");
         xmlDocSetRootElement (doc, root);
 
         xml_add_string (root, "username", cfg->username);
@@ -401,6 +406,8 @@ vgl_user_cfg_write                      (VglUserCfg *cfg)
         xml_add_string (root, "download-dir", cfg->download_dir);
         xml_add_string (root, "imstatus-template", cfg->imstatus_template);
         xml_add_bool (root, "use-proxy", cfg->use_proxy);
+        xml_add_bool (root, "use-system-proxy", cfg->use_system_proxy);
+        xml_add_bool (root, "low-bitrate", cfg->low_bitrate);
         xml_add_bool (root, "discovery-mode", cfg->discovery_mode);
         xml_add_bool (root, "enable-scrobbling", cfg->enable_scrobbling);
         xml_add_bool (root, "im-pidgin", cfg->im_pidgin);
