@@ -1,7 +1,7 @@
 /*
  * vgl-main-window.c -- Main program window
  *
- * Copyright (C) 2007-2010 Igalia, S.L.
+ * Copyright (C) 2007-2011 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3.
@@ -113,8 +113,7 @@ static const button_data addpl_button = {
         N_("Add this track to playlist")
 };
 
-static const char cover_background[] = APP_DATA_DIR "/cover.png";
-static GtkTooltips *tooltips = NULL;
+static const char cover_bg[] = APP_DATA_DIR "/cover.png";
 
 void
 vgl_main_window_run_app                 (void)
@@ -230,9 +229,9 @@ vgl_main_window_update_track_info       (VglMainWindow     *w,
 
         g_string_free(text, TRUE);
 
-        gtk_tooltips_set_tip (tooltips, priv->artist, t->artist, t->artist);
-        gtk_tooltips_set_tip (tooltips, priv->track, t->title, t->title);
-        gtk_tooltips_set_tip (tooltips, priv->album, t->album, t->album);
+        gtk_widget_set_tooltip_text (priv->artist, t->artist);
+        gtk_widget_set_tooltip_text (priv->track, t->title);
+        gtk_widget_set_tooltip_text (priv->album, t->album);
 }
 
 static void
@@ -459,25 +458,25 @@ key_press_cb                            (GtkWidget     *widget,
         int volchange = 0;
         switch (event->keyval) {
 #ifdef MAEMO
-        case GDK_F6:
+        case GDK_KEY_F6:
                 if (win->priv->is_fullscreen) {
                         gtk_window_unfullscreen(GTK_WINDOW(win));
                 } else {
                         gtk_window_fullscreen(GTK_WINDOW(win));
                 }
                 break;
-        case GDK_F7:
+        case GDK_KEY_F7:
 #else
-        case GDK_KP_Add:
-        case GDK_plus:
+        case GDK_KEY_KP_Add:
+        case GDK_KEY_plus:
 #endif
                 volchange = 5;
                 break;
 #ifdef MAEMO
-        case GDK_F8:
+        case GDK_KEY_F8:
 #else
-        case GDK_KP_Subtract:
-        case GDK_minus:
+        case GDK_KEY_KP_Subtract:
+        case GDK_KEY_minus:
 #endif
                 volchange = -5;
                 break;
@@ -564,8 +563,7 @@ image_button_new                        (const button_data *data)
                                     data->button_height);
 
         if (data->tooltip != NULL) {
-                gtk_tooltips_set_tip(tooltips, button,
-                                     _(data->tooltip), _(data->tooltip));
+                gtk_widget_set_tooltip_text (button, _(data->tooltip));
         }
 
         return button;
@@ -578,21 +576,21 @@ vgl_main_window_set_hildon22_accels     (VglMainWindow *win,
 {
         VglMainWindowPrivate *p = win->priv;
         gtk_widget_add_accelerator (p->playbutton, "activate", accel,
-                                    GDK_space, 0, 0);
+                                    GDK_KEY_space, 0, 0);
         gtk_widget_add_accelerator (p->stopbutton, "activate", accel,
-                                    GDK_space, 0, 0);
+                                    GDK_KEY_space, 0, 0);
         gtk_widget_add_accelerator (p->skipbutton, "activate", accel,
-                                    GDK_Right, GDK_CONTROL_MASK, 0);
+                                    GDK_KEY_Right, GDK_CONTROL_MASK, 0);
         gtk_widget_add_accelerator (p->banbutton, "activate", accel,
-                                    GDK_b, GDK_CONTROL_MASK, 0);
+                                    GDK_KEY_b, GDK_CONTROL_MASK, 0);
         gtk_widget_add_accelerator (p->lovebutton, "activate", accel,
-                                    GDK_l, GDK_CONTROL_MASK, 0);
+                                    GDK_KEY_l, GDK_CONTROL_MASK, 0);
         gtk_widget_add_accelerator (p->recommendbutton, "activate", accel,
-                                    GDK_r, GDK_CONTROL_MASK, 0);
+                                    GDK_KEY_r, GDK_CONTROL_MASK, 0);
         gtk_widget_add_accelerator (p->tagbutton, "activate", accel,
-                                    GDK_t, GDK_CONTROL_MASK, 0);
+                                    GDK_KEY_t, GDK_CONTROL_MASK, 0);
         gtk_widget_add_accelerator (p->addplbutton, "activate", accel,
-                                    GDK_a, GDK_CONTROL_MASK, 0);
+                                    GDK_KEY_a, GDK_CONTROL_MASK, 0);
 }
 #endif /* MAEMO5 */
 
@@ -605,8 +603,6 @@ vgl_main_window_init                    (VglMainWindow *self)
         GtkBox *image_box_holder, *image_box_holder2, *labelbox;
         GtkBox *buttonshbox, *secondary_bbox, *secondary_bar_vbox;
         GtkWidget* image_box;
-        GtkRcStyle* image_box_style;
-        char *image_box_bg;
         GtkAccelGroup *accel = gtk_accel_group_new();
         self->priv = priv;
         priv->progressbar_text = g_string_sized_new(30);
@@ -653,14 +649,29 @@ vgl_main_window_init                    (VglMainWindow *self)
         gtk_label_set_ellipsize(GTK_LABEL(priv->album), PANGO_ELLIPSIZE_END);
         /* Cover image */
         image_box = gtk_event_box_new();
-        image_box_style = gtk_rc_style_new();
-        image_box_bg = g_strdup(cover_background);
-        image_box_style->bg_pixmap_name[GTK_STATE_NORMAL] = image_box_bg;
-        image_box_style->bg_pixmap_name[GTK_STATE_ACTIVE] = image_box_bg;
-        image_box_style->bg_pixmap_name[GTK_STATE_PRELIGHT] = image_box_bg;
-        image_box_style->bg_pixmap_name[GTK_STATE_SELECTED] = image_box_bg;
-        image_box_style->bg_pixmap_name[GTK_STATE_INSENSITIVE] = image_box_bg;
-        gtk_widget_modify_style(image_box, image_box_style);
+        {
+#ifdef GTK_TYPE_CSS_PROVIDER
+        guint priority = GTK_STYLE_PROVIDER_PRIORITY_APPLICATION;
+        GtkStyleContext *ctx = gtk_widget_get_style_context (image_box);
+        GtkCssProvider *provider = gtk_css_provider_new ();
+        char *css = g_strdup_printf ("* { background-image: url(\"%s\") }",
+                                     cover_bg);
+        gtk_css_provider_load_from_data (provider, css, -1, NULL);
+        gtk_style_context_add_provider (ctx, GTK_STYLE_PROVIDER (provider),
+                                        priority);
+        g_object_unref (provider);
+        g_free (css);
+#else
+        GtkRcStyle *style = gtk_rc_style_new ();
+        style->bg_pixmap_name[GTK_STATE_NORMAL]      = g_strdup (cover_bg);
+        style->bg_pixmap_name[GTK_STATE_ACTIVE]      = g_strdup (cover_bg);
+        style->bg_pixmap_name[GTK_STATE_PRELIGHT]    = g_strdup (cover_bg);
+        style->bg_pixmap_name[GTK_STATE_SELECTED]    = g_strdup (cover_bg);
+        style->bg_pixmap_name[GTK_STATE_INSENSITIVE] = g_strdup (cover_bg);
+        gtk_widget_modify_style (image_box, style);
+        g_object_unref (style);
+#endif /* GTK_TYPE_CSS_PROVIDER */
+        }
         gtk_widget_set_size_request(GTK_WIDGET(image_box),
                                     COVER_FRAME_WIDTH, COVER_FRAME_HEIGHT);
         priv->album_cover = gtk_image_new();
@@ -675,6 +686,7 @@ vgl_main_window_init                    (VglMainWindow *self)
         priv->progressbar = GTK_PROGRESS_BAR(gtk_progress_bar_new());
         gtk_progress_set_text_alignment(GTK_PROGRESS(priv->progressbar),
                                         0.5, 0.5);
+        gtk_progress_bar_set_show_text (priv->progressbar, TRUE);
 #ifdef MAEMO5
         gtk_widget_set_name ((GtkWidget *) priv->progressbar,
                              "small-progress-bar");
@@ -791,7 +803,6 @@ vgl_main_window_class_init              (VglMainWindowClass *klass)
         GObjectClass *obj_class = (GObjectClass *)klass;
         obj_class->finalize = vgl_main_window_finalize;
         g_type_class_add_private(obj_class, sizeof(VglMainWindowPrivate));
-        if (tooltips == NULL) tooltips = gtk_tooltips_new();
 }
 
 GtkWidget *
