@@ -1,7 +1,7 @@
 /*
  * vgl-object.h -- Very minimalist implementation of ref-counted objects
  *
- * Copyright (C) 2009 Igalia, S.L.
+ * Copyright (C) 2009, 2010 Igalia, S.L.
  * Authors: Alberto Garcia <agarcia@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3
@@ -16,7 +16,9 @@
 G_BEGIN_DECLS
 
 typedef struct {
+#ifndef G_DISABLE_CAST_CHECKS
         int header;
+#endif
         volatile int refcount;
         int objsize;
         GDestroyNotify destroy_func;
