@@ -1,6 +1,9 @@
 /*
  * vgl-sb-plugin.c -- Status bar plugin for Vagalume
- * Copyright (C) 2008 Mario Sanchez Prada <msanchez@igalia.com>
+ *
+ * Copyright (C) 2007-2008 Igalia, S.L.
+ * Authors: Alberto Garcia <agarcia@igalia.com>
+ *          Mario Sanchez Prada <msanchez@igalia.com>
  *
  * This file is part of Vagalume and is published under the GNU GPLv3
  * See the README file for more details.
@@ -44,7 +47,20 @@
         (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
                                       VGL_SB_PLUGIN_TYPE, VglSbPluginPrivate))
 
-typedef struct _VglSbPluginPrivate VglSbPluginPrivate;
+enum {
+        ARTIST_ITEM,
+        TRACK_ITEM,
+        ALBUM_ITEM,
+        PLAY_ITEM,
+        STOP_ITEM,
+        NEXT_ITEM,
+        LOVE_ITEM,
+        BAN_ITEM,
+        SHOW_WIN_ITEM,
+        QUIT_ITEM,
+        N_MENU_ITEMS
+};
+
 struct _VglSbPluginPrivate
 {
         osso_context_t *osso_context;
@@ -62,26 +78,11 @@ struct _VglSbPluginPrivate
         GtkWidget *button;
         GtkWidget *icon;
         GtkWidget *main_panel;
-        GtkWidget *artist_item;
-        GtkWidget *track_item;
-        GtkWidget *album_item;
-        GtkWidget *play_item;
-        GtkWidget *stop_item;
-        GtkWidget *next_item;
-        GtkWidget *love_item;
-        GtkWidget *ban_item;
-        GtkWidget *open_vagalume_item;
-        GtkWidget *close_vagalume_item;
+        GtkWidget *menu_item[N_MENU_ITEMS];
 
-        gint plugin_btn_handler_id;
-        gint main_panel_handler_id;
-        gint play_item_handler_id;
-        gint stop_item_handler_id;
-        gint next_item_handler_id;
-        gint love_item_handler_id;
-        gint ban_item_handler_id;
-        gint open_vagalume_item_handler_id;
-        gint close_vagalume_item_handler_id;
+        gulong plugin_btn_handler_id;
+        gulong main_panel_handler_id;
+        gulong menu_handler_id[N_MENU_ITEMS];
 
         gboolean dispose_has_run;
 };
@@ -126,7 +127,7 @@ static gboolean vagalume_running (VglSbPlugin *vsbp);
 /* Initialization/destruction functions */
 
 static void
-vgl_sb_plugin_class_init (VglSbPluginClass *klass)
+vgl_sb_plugin_class_init                (VglSbPluginClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
         object_class->dispose = vgl_sb_plugin_dispose;
@@ -139,12 +140,14 @@ vgl_sb_plugin_class_init (VglSbPluginClass *klass)
 }
 
 static void
-vgl_sb_plugin_init (VglSbPlugin *vsbp)
+vgl_sb_plugin_init                      (VglSbPlugin *vsbp)
 {
+        int i;
         VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
         GdkPixbuf *icon_pixbuf;
 
         /* Init private attributes to their default values */
+        vsbp->priv = priv;
         priv->osso_context = NULL;
         priv->dbus_connection = NULL;
         priv->dbus_filter_added = FALSE;
@@ -157,16 +160,10 @@ vgl_sb_plugin_init (VglSbPlugin *vsbp)
         priv->button = NULL;
         priv->icon = NULL;
         priv->main_panel = NULL;
-        priv->artist_item = NULL;
-        priv->track_item = NULL;
-        priv->album_item = NULL;
-        priv->play_item = NULL;
-        priv->stop_item = NULL;
-        priv->next_item = NULL;
-        priv->love_item = NULL;
-        priv->ban_item = NULL;
-        priv->open_vagalume_item = NULL;
-        priv->close_vagalume_item = NULL;
+        for (i = 0; i < N_MENU_ITEMS; i++) {
+                priv->menu_item[i] = NULL;
+                priv->menu_handler_id[i] = 0;
+        }
         priv->dispose_has_run = FALSE;
 
         /* Setup libosso */
@@ -213,10 +210,11 @@ vgl_sb_plugin_init (VglSbPlugin *vsbp)
 }
 
 static void
-vgl_sb_plugin_dispose (GObject *object)
+vgl_sb_plugin_dispose                   (GObject *object)
 {
+        int i;
         VglSbPlugin *vsbp = VGL_SB_PLUGIN (object);
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
 
         /* Ensure dispose is called only once */
         if (priv->dispose_has_run) {
@@ -235,20 +233,12 @@ vgl_sb_plugin_dispose (GObject *object)
                                      priv->plugin_btn_handler_id);
         g_signal_handler_disconnect (priv->main_panel,
                                      priv->main_panel_handler_id);
-        g_signal_handler_disconnect (priv->play_item,
-                                     priv->play_item_handler_id);
-        g_signal_handler_disconnect (priv->stop_item,
-                                     priv->stop_item_handler_id);
-        g_signal_handler_disconnect (priv->next_item,
-                                     priv->next_item_handler_id);
-        g_signal_handler_disconnect (priv->love_item,
-                                     priv->love_item_handler_id);
-        g_signal_handler_disconnect (priv->ban_item,
-                                     priv->ban_item_handler_id);
-        g_signal_handler_disconnect (priv->open_vagalume_item,
-                                     priv->open_vagalume_item_handler_id);
-        g_signal_handler_disconnect (priv->close_vagalume_item,
-                                     priv->close_vagalume_item_handler_id);
+        for (i = 0; i < N_MENU_ITEMS; i++) {
+                if (priv->menu_handler_id[ARTIST_ITEM] != 0) {
+                        g_signal_handler_disconnect (priv->menu_item[i],
+                                                     priv->menu_handler_id[i]);
+                }
+        }
 
         /* Destroy local widgets */
         if (priv->main_panel) {
@@ -273,9 +263,9 @@ vgl_sb_plugin_dispose (GObject *object)
 /* Dbus stuff */
 
 static gboolean
-dbus_init(VglSbPlugin *vsbp)
+dbus_init                               (VglSbPlugin *vsbp)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
 
 
         /* Get the D-Bus connection to the session bus */
@@ -304,9 +294,9 @@ dbus_init(VglSbPlugin *vsbp)
         return TRUE;
 }
 
-static void dbus_cleanup (VglSbPlugin *vsbp)
+static void dbus_cleanup                (VglSbPlugin *vsbp)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
 
         /* Remove filter and matching rules */
         if (priv->dbus_filter_added) {
@@ -324,7 +314,9 @@ static void dbus_cleanup (VglSbPlugin *vsbp)
 }
 
 static DBusHandlerResult
-dbus_req_handler (DBusConnection *connection, DBusMessage *message, gpointer data)
+dbus_req_handler                        (DBusConnection *connection,
+                                         DBusMessage    *message,
+                                         gpointer        data)
 {
         VglSbPlugin *vsbp = VGL_SB_PLUGIN (data);
 
@@ -339,16 +331,20 @@ dbus_req_handler (DBusConnection *connection, DBusMessage *message, gpointer dat
 }
 
 static void
-dbus_send_request (VglSbPlugin *vsbp, const gchar *request)
+dbus_send_request                       (VglSbPlugin *vsbp,
+                                         const gchar *request)
 {
         /* Delegate on dbus_send_request_with_params() */
         dbus_send_request_with_params (vsbp, request, DBUS_TYPE_INVALID);
 }
 
 static void
-dbus_send_request_with_params (VglSbPlugin *vsbp, const char *request, int first_type, ...)
+dbus_send_request_with_params           (VglSbPlugin *vsbp,
+                                         const char  *request,
+                                         int          first_type,
+                                         ...)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
         DBusMessage *dbus_msg = NULL;
         va_list ap;
 
@@ -369,9 +365,10 @@ dbus_send_request_with_params (VglSbPlugin *vsbp, const char *request, int first
 }
 
 static void
-notify_handler (VglSbPlugin *vsbp, DBusMessage *message)
+notify_handler                          (VglSbPlugin *vsbp,
+                                         DBusMessage *message)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
         DBusMessageIter iter;
         gchar *type = NULL;
         gboolean msg_handled = FALSE;
@@ -468,16 +465,16 @@ notify_handler (VglSbPlugin *vsbp, DBusMessage *message)
 /* Setters */
 
 static void
-set_visibility (VglSbPlugin *vsbp, gboolean visible)
+set_visibility                          (VglSbPlugin *vsbp,
+                                         gboolean     visible)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
         gboolean old_condition;
 
         g_object_get (vsbp, "condition", &old_condition, NULL);
         if (old_condition != visible)
                 g_object_set (vsbp, "condition", visible, NULL);
 
-        priv->is_visible = visible;
+        vsbp->priv->is_visible = visible;
 
         g_debug ("Setting visibility to '%s'",
                  (visible ? "visible" : "hidden"));
@@ -485,7 +482,9 @@ set_visibility (VglSbPlugin *vsbp, gboolean visible)
 
 
 static void
-set_field (gchar **field, const gchar *text, const gchar *markup_fmt)
+set_field                               (gchar       **field,
+                                         const gchar  *text,
+                                         const gchar  *markup_fmt)
 {
         g_return_if_fail (text != NULL);
         gchar *final_text = NULL;
@@ -514,14 +513,14 @@ set_field (gchar **field, const gchar *text, const gchar *markup_fmt)
 }
 
 static void
-set_track_info (VglSbPlugin *vsbp,
-               const gchar *artist,
-               const gchar *track,
-               const gchar *album)
+set_track_info                          (VglSbPlugin *vsbp,
+                                         const gchar *artist,
+                                         const gchar *track,
+                                         const gchar *album)
 {
         g_return_if_fail(VGL_IS_SB_PLUGIN(vsbp));
 
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
 
         /* Call to set_field (), always with valid data */
         set_field (&priv->artist_string,
@@ -545,7 +544,7 @@ set_track_info (VglSbPlugin *vsbp,
 /* Panel update functions */
 
 static PangoFontDescription *
-get_small_font (GtkWidget *widget)
+get_small_font                          (GtkWidget *widget)
 {
         static PangoFontDescription *new_font = NULL;
 
@@ -558,9 +557,9 @@ get_small_font (GtkWidget *widget)
 }
 
 static void
-main_panel_create (VglSbPlugin *vsbp)
+main_panel_create                       (VglSbPlugin *vsbp)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
         GtkWidget *label;
 
         /* Create main_panel and main_panel items */
@@ -568,83 +567,88 @@ main_panel_create (VglSbPlugin *vsbp)
         gtk_widget_set_size_request (priv->main_panel, MAIN_PANEL_WIDTH, -1);
 
         /* Insensitive items */
-        priv->artist_item = gtk_menu_item_new ();
+        priv->menu_item[ARTIST_ITEM] = gtk_menu_item_new ();
         label = gtk_label_new (NULL);
         gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
         gtk_widget_modify_font (label, get_small_font (label));
         gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
-        gtk_container_add (GTK_CONTAINER (priv->artist_item), label);
-        gtk_widget_set_sensitive (priv->artist_item, FALSE);
+        gtk_container_add (GTK_CONTAINER (priv->menu_item[ARTIST_ITEM]), label);
+        gtk_widget_set_sensitive (priv->menu_item[ARTIST_ITEM], FALSE);
         label->state = GTK_STATE_NORMAL;
 
-        priv->track_item = gtk_menu_item_new ();
+        priv->menu_item[TRACK_ITEM] = gtk_menu_item_new ();
         label = gtk_label_new (NULL);
         gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
         gtk_widget_modify_font (label, get_small_font (label));
         gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
-        gtk_container_add (GTK_CONTAINER (priv->track_item), label);
-        gtk_widget_set_sensitive (priv->track_item, FALSE);
+        gtk_container_add (GTK_CONTAINER (priv->menu_item[TRACK_ITEM]), label);
+        gtk_widget_set_sensitive (priv->menu_item[TRACK_ITEM], FALSE);
         label->state = GTK_STATE_NORMAL;
 
-        priv->album_item = gtk_menu_item_new ();
+        priv->menu_item[ALBUM_ITEM] = gtk_menu_item_new ();
         label = gtk_label_new (NULL);
         gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
         gtk_widget_modify_font (label, get_small_font (label));
         gtk_misc_set_alignment (GTK_MISC(label), 0.0, 0.5);
-        gtk_container_add (GTK_CONTAINER (priv->album_item), label);
-        gtk_widget_set_sensitive (priv->album_item, FALSE);
+        gtk_container_add (GTK_CONTAINER (priv->menu_item[ALBUM_ITEM]), label);
+        gtk_widget_set_sensitive (priv->menu_item[ALBUM_ITEM], FALSE);
         label->state = GTK_STATE_NORMAL;
 
         /* Active items */
-        priv->play_item = gtk_menu_item_new_with_label (PLAY_ITEM_STRING);
-        priv->stop_item = gtk_menu_item_new_with_label (STOP_ITEM_STRING);
-        priv->next_item = gtk_menu_item_new_with_label (SKIP_ITEM_STRING);
-        priv->love_item = gtk_menu_item_new_with_label (LOVE_ITEM_STRING);
-        priv->ban_item = gtk_menu_item_new_with_label (BAN_ITEM_STRING);
-        priv->open_vagalume_item =
+        priv->menu_item[PLAY_ITEM] =
+                gtk_menu_item_new_with_label (PLAY_ITEM_STRING);
+        priv->menu_item[STOP_ITEM] =
+                gtk_menu_item_new_with_label (STOP_ITEM_STRING);
+        priv->menu_item[NEXT_ITEM] =
+                gtk_menu_item_new_with_label (SKIP_ITEM_STRING);
+        priv->menu_item[LOVE_ITEM] =
+                gtk_menu_item_new_with_label (LOVE_ITEM_STRING);
+        priv->menu_item[BAN_ITEM] =
+                gtk_menu_item_new_with_label (BAN_ITEM_STRING);
+        priv->menu_item[SHOW_WIN_ITEM] =
                 gtk_menu_item_new_with_label (SHOW_APP_ITEM_STRING);
-        priv->close_vagalume_item =
+        priv->menu_item[QUIT_ITEM] =
                 gtk_menu_item_new_with_label (CLOSE_APP_ITEM_STRING);
 
         /* Add items to main_panel */
-        gtk_menu_append (priv->main_panel, priv->artist_item);
-        gtk_menu_append (priv->main_panel, priv->track_item);
-        gtk_menu_append (priv->main_panel, priv->album_item);
+        gtk_menu_append (priv->main_panel, priv->menu_item[ARTIST_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[TRACK_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[ALBUM_ITEM]);
         gtk_menu_append (priv->main_panel, gtk_separator_menu_item_new ());
-        gtk_menu_append (priv->main_panel, priv->play_item);
-        gtk_menu_append (priv->main_panel, priv->stop_item);
-        gtk_menu_append (priv->main_panel, priv->next_item);
-        gtk_menu_append (priv->main_panel, priv->love_item);
-        gtk_menu_append (priv->main_panel, priv->ban_item);
+        gtk_menu_append (priv->main_panel, priv->menu_item[PLAY_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[STOP_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[NEXT_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[LOVE_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[BAN_ITEM]);
         gtk_menu_append (priv->main_panel, gtk_separator_menu_item_new ());
-        gtk_menu_append (priv->main_panel, priv->open_vagalume_item);
-        gtk_menu_append (priv->main_panel, priv->close_vagalume_item);
+        gtk_menu_append (priv->main_panel, priv->menu_item[SHOW_WIN_ITEM]);
+        gtk_menu_append (priv->main_panel, priv->menu_item[QUIT_ITEM]);
 
         /* Connect signals */
         priv->main_panel_handler_id =
                 g_signal_connect(priv->main_panel,
                                  "selection-done",
                                  G_CALLBACK(main_panel_hidden), vsbp);
-        priv->play_item_handler_id =
-                g_signal_connect(priv->play_item, "activate",
+        priv->menu_handler_id[PLAY_ITEM] =
+                g_signal_connect(priv->menu_item[PLAY_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
-        priv->stop_item_handler_id =
-                g_signal_connect(priv->stop_item, "activate",
+        priv->menu_handler_id[STOP_ITEM] =
+                g_signal_connect(priv->menu_item[STOP_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
-        priv->next_item_handler_id =
-                g_signal_connect(priv->next_item, "activate",
+        priv->menu_handler_id[NEXT_ITEM] =
+                g_signal_connect(priv->menu_item[NEXT_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
-        priv->love_item_handler_id =
-                g_signal_connect(priv->love_item, "activate",
+        priv->menu_handler_id[LOVE_ITEM] =
+                g_signal_connect(priv->menu_item[LOVE_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
-        priv->ban_item_handler_id =
-                g_signal_connect(priv->ban_item, "activate",
+        priv->menu_handler_id[BAN_ITEM] =
+                g_signal_connect(priv->menu_item[BAN_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
-        priv->open_vagalume_item_handler_id =
-                g_signal_connect(priv->open_vagalume_item, "activate",
+        priv->menu_handler_id[SHOW_WIN_ITEM] =
+                g_signal_connect(priv->menu_item[SHOW_WIN_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
-        priv->close_vagalume_item_handler_id =
-                g_signal_connect(priv->close_vagalume_item, "activate",
+        priv->menu_handler_id[QUIT_ITEM] =
+                g_signal_connect(priv->menu_item[QUIT_ITEM], "activate",
                                  G_CALLBACK (main_panel_item_activated), vsbp);
 
         /* Show widgets */
@@ -652,9 +656,10 @@ main_panel_create (VglSbPlugin *vsbp)
 }
 
 static void
-main_panel_update (VglSbPlugin *vsbp)
+main_panel_update                       (VglSbPlugin *vsbp)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
+        gboolean np = priv->now_playing;
         GtkWidget *label;
 
         if (!priv->running_app) {
@@ -664,45 +669,38 @@ main_panel_update (VglSbPlugin *vsbp)
         }
 
         /* Adjust sentitiveness for main_panel items and show/hide buttons */
-        if (priv->now_playing) {
-                gtk_widget_set_sensitive (priv->play_item, FALSE);
-                gtk_widget_set_sensitive (priv->stop_item, TRUE);
-                gtk_widget_set_sensitive (priv->next_item, TRUE);
-                gtk_widget_set_sensitive (priv->love_item, TRUE);
-                gtk_widget_set_sensitive (priv->ban_item, TRUE);
+        gtk_widget_set_sensitive (priv->menu_item[PLAY_ITEM], !np);
+        gtk_widget_set_sensitive (priv->menu_item[STOP_ITEM], np);
+        gtk_widget_set_sensitive (priv->menu_item[NEXT_ITEM], np);
+        gtk_widget_set_sensitive (priv->menu_item[LOVE_ITEM], np);
+        gtk_widget_set_sensitive (priv->menu_item[BAN_ITEM], np);
 
-                gtk_widget_hide (priv->play_item);
-                gtk_widget_show (priv->stop_item);
+        if (np) {
+                gtk_widget_hide (priv->menu_item[PLAY_ITEM]);
+                gtk_widget_show (priv->menu_item[STOP_ITEM]);
         } else {
                 /* Not playing: set default strings */
                 set_track_info (vsbp, NULL, NULL, NULL);
 
-                gtk_widget_set_sensitive (priv->play_item, TRUE);
-                gtk_widget_set_sensitive (priv->stop_item, FALSE);
-                gtk_widget_set_sensitive (priv->next_item, FALSE);
-                gtk_widget_set_sensitive (priv->love_item, FALSE);
-                gtk_widget_set_sensitive (priv->ban_item, FALSE);
-
-                gtk_widget_show (priv->play_item);
-                gtk_widget_hide (priv->stop_item);
+                gtk_widget_show (priv->menu_item[PLAY_ITEM]);
+                gtk_widget_hide (priv->menu_item[STOP_ITEM]);
         }
-        gtk_widget_show (priv->open_vagalume_item);
-        gtk_widget_show (priv->close_vagalume_item);
 
         /* Detail labels */
-        label = gtk_bin_get_child (GTK_BIN (priv->artist_item));
+        label = gtk_bin_get_child (GTK_BIN (priv->menu_item[ARTIST_ITEM]));
         gtk_label_set_markup (GTK_LABEL (label), priv->artist_string);
 
-        label = gtk_bin_get_child (GTK_BIN (priv->track_item));
+        label = gtk_bin_get_child (GTK_BIN (priv->menu_item[TRACK_ITEM]));
         gtk_label_set_markup (GTK_LABEL (label), priv->track_string);
 
         /* Show / hide the album label depending on its availability */
         if (priv->album_string != NULL) {
-                label = gtk_bin_get_child (GTK_BIN (priv->album_item));
+                label = gtk_bin_get_child (
+                        GTK_BIN (priv->menu_item[ALBUM_ITEM]));
                 gtk_label_set_markup (GTK_LABEL (label), priv->album_string);
-                gtk_widget_show (priv->album_item);
+                gtk_widget_show (priv->menu_item[ALBUM_ITEM]);
         } else {
-                gtk_widget_hide (priv->album_item);
+                gtk_widget_hide (priv->menu_item[ALBUM_ITEM]);
         }
 }
 
@@ -710,13 +708,13 @@ main_panel_update (VglSbPlugin *vsbp)
 /* Signals handlers */
 
 static void
-main_panel_position_func (GtkMenu   *main_panel,
-                          gint      *x,
-                          gint      *y,
-                          gboolean  *push_in,
-                          gpointer   data)
+main_panel_position_func                (GtkMenu  *main_panel,
+                                         gint     *x,
+                                         gint     *y,
+                                         gboolean *push_in,
+                                         gpointer  data)
 {
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (data);
+        VglSbPluginPrivate *priv = VGL_SB_PLUGIN (data)->priv;
 
         GtkRequisition req;
 
@@ -730,17 +728,17 @@ main_panel_position_func (GtkMenu   *main_panel,
 }
 
 static void
-plugin_btn_toggled (GtkWidget *button, gpointer data)
+plugin_btn_toggled                      (GtkWidget *button,
+                                         gpointer   data)
 {
         VglSbPlugin *vsbp = VGL_SB_PLUGIN (data);
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
 
         if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (button)))
                 return;
 
         g_debug ("Plugin button toggled");
 
-        gtk_menu_popup (GTK_MENU (priv->main_panel),
+        gtk_menu_popup (GTK_MENU (vsbp->priv->main_panel),
                         NULL, NULL,
                         main_panel_position_func, vsbp,
                         1,
@@ -748,39 +746,40 @@ plugin_btn_toggled (GtkWidget *button, gpointer data)
 }
 
 static void
-main_panel_item_activated (GtkWidget *item, gpointer data)
+main_panel_item_activated               (GtkWidget *item,
+                                         gpointer   data)
 {
         VglSbPlugin *vsbp = VGL_SB_PLUGIN (data);
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
         const gboolean interactive = TRUE;
 
-        if (item == priv->play_item) {
+        if (item == priv->menu_item[PLAY_ITEM]) {
                 dbus_send_request (vsbp, APP_DBUS_METHOD_PLAY);
                 g_debug ("DBUS request sent: Play");
-        } else if (item == priv->stop_item) {
+        } else if (item == priv->menu_item[STOP_ITEM]) {
                 dbus_send_request (vsbp, APP_DBUS_METHOD_STOP);
                 g_debug ("DBUS request sent: Stop");
-        } else if (item == priv->next_item) {
+        } else if (item == priv->menu_item[NEXT_ITEM]) {
                 dbus_send_request (vsbp, APP_DBUS_METHOD_SKIP);
                 g_debug ("DBUS request sent: Skip");
-        } else if (item == priv->love_item) {
+        } else if (item == priv->menu_item[LOVE_ITEM]) {
                 dbus_send_request_with_params (vsbp,
                                                APP_DBUS_METHOD_LOVETRACK,
                                                DBUS_TYPE_BOOLEAN,
                                                &interactive,
                                                DBUS_TYPE_INVALID);
                 g_debug ("DBUS request sent: LoveTrack");
-        } else if (item == priv->ban_item) {
+        } else if (item == priv->menu_item[BAN_ITEM]) {
                 dbus_send_request_with_params (vsbp,
                                                APP_DBUS_METHOD_BANTRACK,
                                                DBUS_TYPE_BOOLEAN,
                                                &interactive,
                                                DBUS_TYPE_INVALID);
                 g_debug ("DBUS request sent: BanTrack");
-        } else if (item == priv->open_vagalume_item) {
+        } else if (item == priv->menu_item[SHOW_WIN_ITEM]) {
                 dbus_send_request (vsbp, APP_DBUS_METHOD_SHOWWINDOW);
                 g_debug ("DBUS request sent: Show application");
-        } else if (item == priv->close_vagalume_item) {
+        } else if (item == priv->menu_item[QUIT_ITEM]) {
                 dbus_send_request (vsbp, APP_DBUS_METHOD_CLOSEAPP);
                 g_debug ("DBUS request sent: Close application");
         } else {
@@ -789,10 +788,11 @@ main_panel_item_activated (GtkWidget *item, gpointer data)
 }
 
 static void
-main_panel_hidden (GtkWidget *main_panel, gpointer data)
+main_panel_hidden                       (GtkWidget *main_panel,
+                                         gpointer   data)
 {
         VglSbPlugin *vsbp = VGL_SB_PLUGIN (data);
-        VglSbPluginPrivate *priv = VGL_SB_PLUGIN_GET_PRIVATE (vsbp);
+        VglSbPluginPrivate *priv = vsbp->priv;
 
         g_debug ("Main panel hidden");
 
@@ -803,7 +803,7 @@ main_panel_hidden (GtkWidget *main_panel, gpointer data)
 /* Utility functions */
 
 static gboolean
-vagalume_running (VglSbPlugin *vsbp)
+vagalume_running                        (VglSbPlugin *vsbp)
 {
         HDWM *hdwm;
         HDWMEntryInfo *info = NULL;
