@@ -1,7 +1,7 @@
 /*
  * vgl-tray-icon.c -- Freedesktop tray icon
  *
- * Copyright (C) 2007-2009 Igalia, S.L.
+ * Copyright (C) 2007-2009, 2011 Igalia, S.L.
  * Authors: Mario Sanchez Prada <msanchez@igalia.com>
  *          Alberto Garcia <agarcia@igalia.com>
  *
@@ -142,7 +142,8 @@ vgl_tray_icon_init                      (VglTrayIcon *vti)
 
         /* Set icon and tooltip */
         gtk_status_icon_set_from_file (priv->tray_icon, APP_ICON);
-        gtk_status_icon_set_tooltip(priv->tray_icon, TOOLTIP_DEFAULT_STRING);
+        gtk_status_icon_set_tooltip_text (priv->tray_icon,
+                                          TOOLTIP_DEFAULT_STRING);
         gtk_status_icon_set_visible(priv->tray_icon, TRUE);
 
         /* Init libnotify */
@@ -518,11 +519,18 @@ show_notification                       (VglTrayIcon *vti,
         /* Create the notification if not already created */
         if (priv->notification == NULL) {
                 priv->notification =
+#if !defined(NOTIFY_VERSION_MINOR) || (NOTIFY_VERSION_MAJOR == 0 && NOTIFY_VERSION_MINOR < 7)
                         notify_notification_new_with_status_icon (
                                 notification_summary,
                                 notification_body,
                                 NULL,
                                 priv->tray_icon);
+#else
+                        notify_notification_new (
+                                notification_summary,
+                                notification_body,
+                                NULL);
+#endif
         } else {
                 notify_notification_update (priv->notification,
                                             notification_summary,
@@ -563,7 +571,8 @@ notify_playback_idle                    (gpointer userdata)
                 tooltip_string = g_strdup_printf (TOOLTIP_FORMAT_STRING,
                                                   d->track->title,
                                                   d->track->artist);
-                gtk_status_icon_set_tooltip(priv->tray_icon, tooltip_string);
+                gtk_status_icon_set_tooltip_text (priv->tray_icon,
+                                                  tooltip_string);
 
                 g_free (tooltip_string);
 
@@ -572,8 +581,8 @@ notify_playback_idle                    (gpointer userdata)
                         show_notification (d->vti, d->track);
                 }
         } else {
-                gtk_status_icon_set_tooltip (priv->tray_icon,
-                                             TOOLTIP_DEFAULT_STRING);
+                gtk_status_icon_set_tooltip_text (priv->tray_icon,
+                                                  TOOLTIP_DEFAULT_STRING);
         }
 
         /* Cleanup */
